/*
 * This example has been extensively modified by:
 * Luis R. Hilario B.(Luis Digital) www.luisdigital.com
 *
 * Purpose: USB mouse with accelerometer Demo
 * Version: 1.0
 * Date: 7 Feb. 2011
 */


/*----------------------------------------------------------------------------
 *      Name:    DEMO.C
 *      Purpose: USB HID Demo
 *      Version: V1.20
 *----------------------------------------------------------------------------
 *      This software is supplied "AS IS" without any warranties, express,
 *      implied or statutory, including but not limited to the implied
 *      warranties of fitness for purpose, satisfactory quality and
 *      noninfringement. Keil extends you a royalty-free right to reproduce
 *      and distribute executable files created using this software for use
 *      on NXP Semiconductors LPC microcontroller devices only. Nothing else 
 *      gives you the right to use this software.
 *
 * Copyright (c) 2009 Keil - An ARM Company. All rights reserved.
 *---------------------------------------------------------------------------*/

#include "LPC13xx.h"                        /* LPC13xx definitions */

#include "usb.h"
#include "usbcfg.h"
#include "usbhw.h"
#include "usbcore.h"
#include "gpio.h"
#include "demo.h"
#include "config.h"

#include "adc.h"

#ifdef ADC_DEBUG
//#include "stdio.h"
#endif

#define     EN_TIMER32_1    (1<<10)
#define     EN_IOCON        (1<<16)
#define     EN_USBREG       (1<<14)

extern volatile uint32_t ADCValue[ADC_NUM];
extern volatile uint32_t ADCIntDone;

#define ADC_COUNT_MAX 1023
#define SUPPLY_VOLTAGE 3.30

#define DesY 10//43
#define DesX 0//43

/*
 * 1.79 V = 10 degrees
 * 1.51 V = -10 degrees
 *
 */
#define ADCP (1.79 * ADC_COUNT_MAX)/SUPPLY_VOLTAGE
#define ADCN (1.51 * ADC_COUNT_MAX)/SUPPLY_VOLTAGE

enum Axis {Z = 1, Y, X};

/*
 *  Get HID Input Report -> InReport
 */
void GetInReport ()
{
    if ((ADCValue[Y]-DesY) > ADCP) {	// Down
    	InReport[2] = ((ADCValue[Y]-DesY) -ADCP)/2;
    }
    else {
    	if ((ADCValue[Y]-DesY) < ADCN) InReport[2] = (signed short)((ADCValue[Y]-DesY)-ADCN)/2; // Up
    };

    if (ADCValue[X] > ADCP) {
    	InReport[1] = (signed short)(ADCP-ADCValue[X])/2; // Left
    }
    else {
    	if (ADCValue[X] < ADCN) InReport[1] = (ADCN -ADCValue[X])/2; // Right
    };

    InReport[0] = ((~INPUT1_CPORT->DATA)&192) >> 6; // Buttons (Left & Right)

  return;
}


/*
 *  Set HID Output Report <- OutReport
 */
void SetOutReport ()
{

}

int main (void)
{
	/* Initialize ADC  */
	ADCInit(ADC_CLK);

	/* Enable Timer32_1, IOCON, and USB blocks */
	LPC_SYSCON->SYSAHBCLKCTRL |= (EN_TIMER32_1 | EN_IOCON | EN_USBREG);

	/* PLL and pin init function */
	USBIOClkConfig();

	/* USB Initialization */
	USB_Init();

	/* USB Connect (if SoftConnect switch implemented) */
	USB_Connect(1);


	/*
	 * Buttons
	 * PIO1_7 Right
	 * PIO1_6 Left
	 */

	GPIOSetDir(1,7,0);
	GPIOSetDir(1,6,0);

	uint32_t i;

	while(1){
		  for ( i = 1; i < 4; i++ ) {
			  ADCRead( i );
			  while (!ADCIntDone);
			  ADCIntDone = 0;
		  };
		  __WFI();
	}

}
